@@ -1,4 +1,4 @@
-#!/usr/share/ucs-test/runner /usr/bin/pytest-3 -s
+#!/usr/share/ucs-test/runner pytest-3 -s
 ## tags: [udm-net,apptest]
 ## roles: [domaincontroller_master]
 ## exposure: careful
@@ -6,11 +6,9 @@
 ##   - univention-config
 ##   - univention-directory-manager-tools
 
-from __future__ import print_function
-
-from univention.testing import utils
 import univention.testing.strings as uts
 import univention.uldap as uldap
+from univention.testing import utils
 
 
 class Test_UDMNetwork(object):
