@@ -1,6 +1,6 @@
 import subprocess
 import time
-from typing import Callable, Iterator, Type  # noqa F401
+from typing import Callable, Iterator, Type  # noqa: F401
 
 import pytest
 
