@@ -37,10 +37,10 @@ from argparse import ArgumentParser, ArgumentDefaultsHelpFormatter
 from datetime import datetime
 from os import path
 from sys import exit
-from typing import Any, Dict, Iterable, Optional, Tuple  # noqa F401
+from typing import Any, Dict, Iterable, Optional, Tuple  # noqa: F401
 
 from six.moves.html_parser import HTMLParser
-from six.moves.http_client import HTTPSConnection, HTTPException, HTTPResponse  # noqa F401
+from six.moves.http_client import HTTPSConnection, HTTPException, HTTPResponse  # noqa: F401
 from six.moves.urllib.parse import urlencode
 
 
