@@ -32,7 +32,6 @@ Common functions used by tests.
 from __future__ import print_function
 
 import functools
-import inspect
 import os
 import socket
 import subprocess
@@ -212,7 +211,6 @@ def verify_ldap_object(
 	:raises LDAPObjectValueMissing: when a value listed in `expected_attr` is missing in the LDAP object
 	:raises LDAPObjectUnexpectedValue: if `strict=True` and a multi-value attribute of the LDAP object
 		has more values than were listed in `expected_attr` or an `not_expected_attr` was found
-	:raises TypeError: if the value of `pre_check` is not a function object
 	"""
 	ucr = UCR
 	ucr.load()
@@ -220,8 +218,6 @@ def verify_ldap_object(
 	delay = int(ucr.get("tests/verify_ldap_object/delay", delay))
 
 	if pre_check:
-		if not inspect.isfunction(pre_check) or inspect.ismethod(pre_check):
-			raise TypeError("Value of argument 'pre_check' is not a function: {!r}".format(pre_check))
 		pre_check(**(pre_check_kwargs or {}))
 
 	return retry_on_error(
@@ -232,7 +228,7 @@ def verify_ldap_object(
 
 
 def __verify_ldap_object(baseDn, expected_attr=None, strict=True, should_exist=True, primary=False, not_expected_attr=None):
-	# type: (str, Optional[Dict[str, str]], bool, bool, bool) -> None
+	# type: (str, Optional[Dict[str, str]], bool, bool, bool, Optional[Dict[str, str]]) -> None
 	if expected_attr is None:
 		expected_attr = {}
 	if not_expected_attr is None:
@@ -276,7 +272,7 @@ def __verify_ldap_object(baseDn, expected_attr=None, strict=True, should_exist=T
 		if intersection:
 			unexpected_values[attribute] = intersection
 
-	mixed = dict((key, (values_missing.get(key), unexpected_values.get(key))) for key in list(values_missing) + list(unexpected_values))
+	mixed = {key: (values_missing.get(key), unexpected_values.get(key)) for key in list(values_missing) + list(unexpected_values)}
 	msg = u'DN: %s\n%s\n' % (
 		baseDn,
 		u'\n'.join(
@@ -505,7 +501,7 @@ def wait_for_replication_from_local_samba_to_local_openldap(replication_postrun=
 	# the order matters!
 	ucr = UCR
 	ucr.load()
-	if ucr.get('server/role') in ('domaincontroller_backup', 'domaincontroller_slave'):
+	if ucr.get('server/role') in {'domaincontroller_backup', 'domaincontroller_slave'}:
 		conditions.append((ReplicationType.DRS, ldap_filter))
 	if ucr.get('samba4/ldap/base'):
 		conditions.append((ReplicationType.S4C_FROM_UCS, ldap_filter))
